==> jc-1.4.0.tar.gz: java/security/spec/EncodedKeySpec.c <==
// public abstract class java.security.spec.EncodedKeySpec

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 76558bda43f0601d java_security_spec_EncodedKeySpec
// @dep_class e5bd533daf8dcb9a java_security_spec_KeySpec

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_security_spec_EncodedKeySpec
// @dep_header java_security_spec_KeySpec

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/security/spec/EncodedKeySpec.h"
#include "java/security/spec/KeySpec.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private byte[] encodedKey
static _jc_field _jc_java_security_spec_EncodedKeySpec$field_info$encodedKey = {
	.name=		"encodedKey",
	.signature=	"[B",
	.class=		&_jc_java_security_spec_EncodedKeySpec$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_security_spec_EncodedKeySpec$object, refs[-1].java_security_spec_EncodedKeySpec.encodedKey),
};

// Fields
static _jc_field *const _jc_java_security_spec_EncodedKeySpec$fields[] = {
	&_jc_java_security_spec_EncodedKeySpec$field_info$encodedKey
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(byte[])
//

static _jc_linenum _jc_java_security_spec_EncodedKeySpec$linenum_table$_init$aaa7e255fe505158[];

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$_init$aaa7e255fe505158[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_security_spec_EncodedKeySpec$param_types$_init$aaa7e255fe505158[] = {
	&_jc_byte$array$prim$type
};

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$_init$aaa7e255fe505158 = {
	.name=			"<init>",
	.signature=		"([B)V",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.param_types=		&_jc_java_security_spec_EncodedKeySpec$param_types$_init$aaa7e255fe505158,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$_init$aaa7e255fe505158,
	.signature_hash=	_JC_JLONG(0xaaa7e255fe505158),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$_init$aaa7e255fe505158,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_security_spec_EncodedKeySpec$linenum_table$_init$aaa7e255fe505158
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_spec_EncodedKeySpec, _init$aaa7e255fe505158);

void
_jc_java_security_spec_EncodedKeySpec$method$_init$aaa7e255fe505158(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this, _jc_byte_array *param0)
{
	struct _jc_java_security_spec_EncodedKeySpec$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	_JC_REF_FIELD(env, r0, java_security_spec_EncodedKeySpec, encodedKey) = r1;
	_JC_LINE_NUMBER(62);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public byte[] getEncoded()
//

static _jc_linenum _jc_java_security_spec_EncodedKeySpec$linenum_table$getEncoded$eaf136136217eb89[];

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$getEncoded$eaf136136217eb89[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$getEncoded$eaf136136217eb89 = {
	.name=			"getEncoded",
	.signature=		"()[B",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$getEncoded$eaf136136217eb89,
	.signature_hash=	_JC_JLONG(0xeaf136136217eb89),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_spec_EncodedKeySpec$vtable, java_security_spec_EncodedKeySpec.getEncoded$eaf136136217eb89) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_security_spec_EncodedKeySpec$linenum_table$getEncoded$eaf136136217eb89
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_spec_EncodedKeySpec, getEncoded$eaf136136217eb89);

_jc_byte_array *
_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this)
{
	struct _jc_java_security_spec_EncodedKeySpec$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_security_spec_EncodedKeySpec, encodedKey);
	return r1;
}

//
// public abstract java.lang.String getFormat()
//

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$getFormat$10e2c7b1e3bfcc3b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b = {
	.name=			"getFormat",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$getFormat$10e2c7b1e3bfcc3b,
	.signature_hash=	_JC_JLONG(0x10e2c7b1e3bfcc3b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_spec_EncodedKeySpec$vtable, java_security_spec_EncodedKeySpec.getFormat$10e2c7b1e3bfcc3b) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object *
_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_security_spec_EncodedKeySpec$methods[] = {
	&_jc_java_security_spec_EncodedKeySpec$method_info$_init$aaa7e255fe505158,
	&_jc_java_security_spec_EncodedKeySpec$method_info$getEncoded$eaf136136217eb89,
	&_jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$interfaces[] = {
	&_jc_java_security_spec_KeySpec$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_26[] = {
	&_jc_java_security_spec_KeySpec$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_29[] = {
	&_jc_java_security_spec_EncodedKeySpec$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_26,
	[29]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_29,
	[113]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_security_spec_EncodedKeySpec$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/security/spec/KeySpec",	_JC_JLONG(0xe5bd533daf8dcb9a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_security_spec_EncodedKeySpec$vtype _jc_java_security_spec_EncodedKeySpec$type = {
    .type= {
	.name=			"java/security/spec/EncodedKeySpec",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_security_spec_EncodedKeySpec$interfaces) / sizeof(*_jc_java_security_spec_EncodedKeySpec$interfaces),
	.interfaces=		_jc_java_security_spec_EncodedKeySpec$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x76558bda43f0601d),
		.source_file=		"EncodedKeySpec.java",
		.instance_size=		sizeof(_jc_java_security_spec_EncodedKeySpec$refs) + sizeof(_jc_java_security_spec_EncodedKeySpec$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_security_spec_EncodedKeySpec$fields) / sizeof(*_jc_java_security_spec_EncodedKeySpec$fields),
		.fields=		_jc_java_security_spec_EncodedKeySpec$fields,
		.num_methods=		sizeof(_jc_java_security_spec_EncodedKeySpec$methods) / sizeof(*_jc_java_security_spec_EncodedKeySpec$methods),
		.methods=		_jc_java_security_spec_EncodedKeySpec$methods,
		.instanceof_hash_table=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_security_spec_EncodedKeySpec$class_depends) / sizeof(*_jc_java_security_spec_EncodedKeySpec$class_depends),
		.class_depends=		_jc_java_security_spec_EncodedKeySpec$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_security_spec_EncodedKeySpec= {
	    .getEncoded$eaf136136217eb89=
		&_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89,
	    .getFormat$10e2c7b1e3bfcc3b=
		&_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b,
	},
    }
};

==> jc-1.4.5.tar.gz: java/security/spec/EncodedKeySpec.c <==
// public abstract class java.security.spec.EncodedKeySpec

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 76558bda43f0601d java_security_spec_EncodedKeySpec
// @dep_class e5bd533daf8dcb9a java_security_spec_KeySpec

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_security_spec_EncodedKeySpec
// @dep_header java_security_spec_KeySpec

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/security/spec/EncodedKeySpec.h"
#include "java/security/spec/KeySpec.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private byte[] encodedKey
static _jc_field _jc_java_security_spec_EncodedKeySpec$field_info$encodedKey = {
	.name=		"encodedKey",
	.signature=	"[B",
	.class=		&_jc_java_security_spec_EncodedKeySpec$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_security_spec_EncodedKeySpec$object, refs[-1].java_security_spec_EncodedKeySpec.encodedKey),
};

// Fields
static _jc_field *const _jc_java_security_spec_EncodedKeySpec$fields[] = {
	&_jc_java_security_spec_EncodedKeySpec$field_info$encodedKey
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(byte[])
//

static _jc_linenum _jc_java_security_spec_EncodedKeySpec$linenum_table$_init$aaa7e255fe505158[];

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$_init$aaa7e255fe505158[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_security_spec_EncodedKeySpec$param_types$_init$aaa7e255fe505158[] = {
	&_jc_byte$array$prim$type
};

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$_init$aaa7e255fe505158 = {
	.name=			"<init>",
	.signature=		"([B)V",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.param_types=		&_jc_java_security_spec_EncodedKeySpec$param_types$_init$aaa7e255fe505158,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$_init$aaa7e255fe505158,
	.signature_hash=	_JC_JLONG(0xaaa7e255fe505158),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$_init$aaa7e255fe505158,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_security_spec_EncodedKeySpec$linenum_table$_init$aaa7e255fe505158
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_spec_EncodedKeySpec, _init$aaa7e255fe505158);

void _JC_JCNI_ATTR
_jc_java_security_spec_EncodedKeySpec$method$_init$aaa7e255fe505158(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this, _jc_byte_array *param0)
{
	struct _jc_java_security_spec_EncodedKeySpec$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	_JC_REF_FIELD(env, r0, java_security_spec_EncodedKeySpec, encodedKey) = r1;
	_JC_LINE_NUMBER(62);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public byte[] getEncoded()
//

static _jc_linenum _jc_java_security_spec_EncodedKeySpec$linenum_table$getEncoded$eaf136136217eb89[];

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$getEncoded$eaf136136217eb89[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$getEncoded$eaf136136217eb89 = {
	.name=			"getEncoded",
	.signature=		"()[B",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$getEncoded$eaf136136217eb89,
	.signature_hash=	_JC_JLONG(0xeaf136136217eb89),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_spec_EncodedKeySpec$vtable, java_security_spec_EncodedKeySpec.getEncoded$eaf136136217eb89) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_security_spec_EncodedKeySpec$linenum_table$getEncoded$eaf136136217eb89
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_spec_EncodedKeySpec, getEncoded$eaf136136217eb89);

_jc_byte_array * _JC_JCNI_ATTR
_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this)
{
	struct _jc_java_security_spec_EncodedKeySpec$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_security_spec_EncodedKeySpec, encodedKey);
	return r1;
}

//
// public abstract java.lang.String getFormat()
//

static const unsigned char _jc_java_security_spec_EncodedKeySpec$param_ptypes$getFormat$10e2c7b1e3bfcc3b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b = {
	.name=			"getFormat",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_spec_EncodedKeySpec$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_spec_EncodedKeySpec$param_ptypes$getFormat$10e2c7b1e3bfcc3b,
	.signature_hash=	_JC_JLONG(0x10e2c7b1e3bfcc3b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_spec_EncodedKeySpec$vtable, java_security_spec_EncodedKeySpec.getFormat$10e2c7b1e3bfcc3b) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *const env, _jc_java_security_spec_EncodedKeySpec$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_security_spec_EncodedKeySpec$methods[] = {
	&_jc_java_security_spec_EncodedKeySpec$method_info$_init$aaa7e255fe505158,
	&_jc_java_security_spec_EncodedKeySpec$method_info$getEncoded$eaf136136217eb89,
	&_jc_java_security_spec_EncodedKeySpec$method_info$getFormat$10e2c7b1e3bfcc3b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$interfaces[] = {
	&_jc_java_security_spec_KeySpec$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_26[] = {
	&_jc_java_security_spec_KeySpec$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_29[] = {
	&_jc_java_security_spec_EncodedKeySpec$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_security_spec_EncodedKeySpec$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_26,
	[29]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_29,
	[101]=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_security_spec_EncodedKeySpec$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/security/spec/KeySpec",	_JC_JLONG(0xe5bd533daf8dcb9a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_security_spec_EncodedKeySpec$vtype _jc_java_security_spec_EncodedKeySpec$type = {
    .type= {
	.name=			"java/security/spec/EncodedKeySpec",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_security_spec_EncodedKeySpec$interfaces) / sizeof(*_jc_java_security_spec_EncodedKeySpec$interfaces),
	.interfaces=		_jc_java_security_spec_EncodedKeySpec$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x76558bda43f0601d),
		.source_file=		"EncodedKeySpec.java",
		.instance_size=		sizeof(_jc_java_security_spec_EncodedKeySpec$refs) + sizeof(_jc_java_security_spec_EncodedKeySpec$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_security_spec_EncodedKeySpec$fields) / sizeof(*_jc_java_security_spec_EncodedKeySpec$fields),
		.fields=		_jc_java_security_spec_EncodedKeySpec$fields,
		.num_methods=		sizeof(_jc_java_security_spec_EncodedKeySpec$methods) / sizeof(*_jc_java_security_spec_EncodedKeySpec$methods),
		.methods=		_jc_java_security_spec_EncodedKeySpec$methods,
		.instanceof_hash_table=	_jc_java_security_spec_EncodedKeySpec$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_security_spec_EncodedKeySpec$class_depends) / sizeof(*_jc_java_security_spec_EncodedKeySpec$class_depends),
		.class_depends=		_jc_java_security_spec_EncodedKeySpec$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_security_spec_EncodedKeySpec= {
	    .getEncoded$eaf136136217eb89=
		&_jc_java_security_spec_EncodedKeySpec$method$getEncoded$eaf136136217eb89,
	    .getFormat$10e2c7b1e3bfcc3b=
		&_jc_java_security_spec_EncodedKeySpec$method$getFormat$10e2c7b1e3bfcc3b,
	},
    }
};
